<?xml version="1.0" encoding="UTF-8"?>
<!--
Licensed Materials - Property of IBM
5724-L01
(C) Copyright IBM Corporation 2005, 2010. All Rights Reserved.
US Government Users Restricted Rights- Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
               xmlns:xalan="http://xml.apache.org/xslt"
               xmlns:staff="http://www.ibm.com/schemas/workflow/wswf/plugins/staff"
               xmlns:sur="http://www.ibm.com/schemas/workflow/wswf/plugins/staff/userregistry"
               version="1.0">

  <xsl:output standalone="no"
              encoding="UTF-8"
              omit-xml-declaration="no"
              media-type="text/xml"
              method="xml"
              indent="yes"
              version="1.0"/>

  <xsl:strip-space elements="*"/>



<!-- Begin global variables -->
  <xsl:variable name="threshold">1000000</xsl:variable>
<!-- End global variables -->



<!-- Begin global dispatching -->
  <xsl:template match="/staff:verb">
    <xsl:variable name="verb1">
      <xsl:value-of select="staff:name/text()"/>
    </xsl:variable>

    <xsl:variable name="verb">
      <xsl:value-of select="normalize-space($verb1)" />
    </xsl:variable>		

    <xsl:choose>
	
      <xsl:when test="$verb='Group Members without Named Users'">
	<xsl:call-template name="GroupMembersWithoutNamedUsers"/>
      </xsl:when>	
      <xsl:when test="$verb='Users'">
        <xsl:call-template name="Users"/>
      </xsl:when>
      <xsl:when test="$verb='Users by user ID'">
        <xsl:call-template name="UsersByUserID"/>
      </xsl:when>
      <xsl:when test="$verb='Users by user ID without Named Users'">
	<xsl:call-template name="UsersByUserIDWithoutNamedUsers"/>
      </xsl:when>	
      <xsl:when test="$verb='Group Members'">
        <xsl:call-template name="GroupMembers"/>
      </xsl:when>
      <xsl:when test="$verb='Role Members'">
        <xsl:message terminate="no">ERROR: Verb 'Role Members' is not supported by the UserRegistryStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Department Members'">
        <xsl:message terminate="no">ERROR: Verb 'Department Members' is not supported by the UserRegistryStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Manager of Employee'">
        <xsl:message terminate="no">ERROR: Verb 'Manager of Employee' is not supported by the UserRegistryStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Manager of Employee by user ID'">
        <xsl:message terminate="no">ERROR: Verb 'Manager of Employee by user ID' is not supported by the UserRegistryStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Person Search'">
        <xsl:call-template name="PersonSearch"/>
      </xsl:when>
      <xsl:when test="$verb='Group Search'">
        <xsl:call-template name="GroupSearch"/>
      </xsl:when>
      <xsl:when test="$verb='Native Query'">
        <xsl:call-template name="NativeQuery"/>
      </xsl:when>
      <xsl:when test="$verb='Everybody'">
        <xsl:call-template name="Everybody"/>
      </xsl:when>
      <xsl:when test="$verb='Nobody'">
        <xsl:call-template name="Nobody"/>
      </xsl:when>
      <xsl:when test="$verb='Group'">
        <xsl:call-template name="Group"/>
      </xsl:when>
      <xsl:when test="$verb='Groups'">
        <xsl:call-template name="Groups"/>
      </xsl:when>
      <xsl:when test="$verb='Users by user ID and groups'">
        <xsl:call-template name="UsersByUserIDAndGroups"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:message terminate="no">ERROR: Unsupported verb: '<xsl:value-of select="$verb"/>'.</xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
<!-- End global dispatching -->



<!-- Begin template Users and children -->
  <xsl:template name="Users">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='Name']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeName1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeName2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeName3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeName4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeName5']"/>
    </xsl:variable>

    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetUser">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </sur:staffQueries>
  </xsl:template>
    

  <xsl:template name="GetUser">
    <xsl:param name="username">default</xsl:param>
    <sur:user>
      <xsl:attribute name="name">
        <xsl:value-of select="$username"/>
      </xsl:attribute>
    </sur:user>
  </xsl:template>
<!-- End template Users and children -->



<!-- Begin template UsersByUserID and children -->
  <xsl:template name="UsersByUserID">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='UserID']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
    </xsl:variable>

    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetUserByID">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </sur:staffQueries>
  </xsl:template>

  <xsl:template name="GetUserByID">
    <xsl:param name="username">default</xsl:param>
    <sur:userID>
      <xsl:attribute name="name">
        <xsl:value-of select="$username"/>
      </xsl:attribute>
    </sur:userID>
  </xsl:template>
<!-- End template UsersByUserID and children -->



<!-- Begin template UsersByUserIDWithoutNamedUsers -->
	<xsl:template name="UsersByUserIDWithoutNamedUsers">
		<xsl:variable name="Name0">
			<xsl:value-of select="staff:parameter[@id='UserID']"/>
		</xsl:variable>
		<xsl:variable name="Name1">
			<xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
		</xsl:variable>
		<xsl:variable name="Name2">
			<xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
		</xsl:variable>
        <xsl:variable name="Name3">
            <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
        </xsl:variable>
        <xsl:variable name="Name4">
            <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
        </xsl:variable>
        <xsl:variable name="Name5">
            <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
        </xsl:variable>
		<sur:staffQueries>
			<xsl:call-template name="GetUserByID">
				<xsl:with-param name="username">
					<xsl:value-of select="$Name0"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:if test="$Name1!=''">
				<xsl:call-template name="GetUserByID">
					<xsl:with-param name="username">
						<xsl:value-of select="$Name1"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$Name2!=''">
				<xsl:call-template name="GetUserByID">
					<xsl:with-param name="username">
						<xsl:value-of select="$Name2"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$Name3!=''">
				<xsl:call-template name="GetUserByID">
					<xsl:with-param name="username">
						<xsl:value-of select="$Name3"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$Name4!=''">
				<xsl:call-template name="GetUserByID">
					<xsl:with-param name="username">
						<xsl:value-of select="$Name4"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$Name5!=''">
				<xsl:call-template name="GetUserByID">
					<xsl:with-param name="username">
						<xsl:value-of select="$Name5"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

			<sur:remove>
				<xsl:attribute name="value"><xsl:value-of select="staff:parameter[@id='NamedUsers']"/></xsl:attribute>
			</sur:remove>			
			
		</sur:staffQueries>
	</xsl:template>
<!-- End template UsersByUserIDWithoutNamedUsers -->



<!-- Begin template Group -->
  <xsl:template name="Group">
    <xsl:variable name="GroupID">
      <xsl:value-of select="staff:parameter[@id='GroupID']"/>
    </xsl:variable>

    <sur:staffQueries>
      <xsl:call-template name="GetGroup">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$GroupID"/>
        </xsl:with-param>
      </xsl:call-template>
    </sur:staffQueries>
  </xsl:template>

  <xsl:template name="GetGroup">
    <xsl:param name="groupname">default</xsl:param>
    <sur:groupID>
      <xsl:attribute name="name">
        <xsl:value-of select="$groupname"/>
      </xsl:attribute>
    </sur:groupID>
  </xsl:template>
<!-- End template Group -->



<!-- Begin template Groups -->
  <xsl:template name="Groups">
    <xsl:variable name="GroupID0">
      <xsl:value-of select="staff:parameter[@id='GroupID']"/>
    </xsl:variable>
    <xsl:variable name="GroupID1">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID1']"/>
    </xsl:variable>
    <xsl:variable name="GroupID2">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID2']"/>
    </xsl:variable>
    <xsl:variable name="GroupID3">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID3']"/>
    </xsl:variable>
    <xsl:variable name="GroupID4">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID4']"/>
    </xsl:variable>
    <xsl:variable name="GroupID5">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID5']"/>
    </xsl:variable>

    <sur:staffQueries>
      <xsl:call-template name="GetGroup">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$GroupID0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$GroupID1!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID2!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID3!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID4!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID5!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </sur:staffQueries>
  </xsl:template>
<!-- End template Groups -->



<!-- Begin template UsersByUserIDAndGroups -->
  <xsl:template name="UsersByUserIDAndGroups">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='UserID']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID5']"/>
    </xsl:variable>
    <xsl:variable name="GroupID0">
      <xsl:value-of select="staff:parameter[@id='GroupID']"/>
    </xsl:variable>
    <xsl:variable name="GroupID1">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID1']"/>
    </xsl:variable>
    <xsl:variable name="GroupID2">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID2']"/>
    </xsl:variable>
    <xsl:variable name="GroupID3">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID3']"/>
    </xsl:variable>
    <xsl:variable name="GroupID4">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID4']"/>
    </xsl:variable>
    <xsl:variable name="GroupID5">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID5']"/>
    </xsl:variable>

    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetUserByID">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUserByID">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:call-template name="GetGroup">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$GroupID0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$GroupID1!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID2!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID3!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID4!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID5!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </sur:staffQueries>
  </xsl:template>
<!-- End template UsersByUserIDAndGroups -->


<!-- Begin template GroupMembers and children -->
  <xsl:template name="GroupMembers">
    <xsl:variable name="Group0">
      <xsl:value-of select="staff:parameter[@id='GroupName']"/>
    </xsl:variable>
    <xsl:variable name="Group1">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupName1']"/>
    </xsl:variable>
    <xsl:variable name="Group2">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupName2']"/>
    </xsl:variable>
    <xsl:variable name="Group3">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupName3']"/>
    </xsl:variable>
    <xsl:variable name="Group4">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupName4']"/>
    </xsl:variable>
    <xsl:variable name="Group5">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupName5']"/>
    </xsl:variable>

    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetGroupMembers">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$Group0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Group1!=''">
        <xsl:call-template name="GetGroupMembers">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$Group1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Group2!=''">
        <xsl:call-template name="GetGroupMembers">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$Group2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Group3!=''">
        <xsl:call-template name="GetGroupMembers">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$Group3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Group4!=''">
        <xsl:call-template name="GetGroupMembers">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$Group4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Group5!=''">
        <xsl:call-template name="GetGroupMembers">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$Group5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </sur:staffQueries>
  </xsl:template>

  <xsl:template name="GetGroupMembers">
    <xsl:param name="groupname">default</xsl:param>
    <sur:usersOfGroup>
      <xsl:attribute name="groupName">
        <xsl:value-of select="$groupname"/>
      </xsl:attribute>
    </sur:usersOfGroup>
  </xsl:template>
<!-- End template GroupMembers and children -->


<!-- Begin template GroupMembersWithoutNamedUsers -->
  <xsl:template name="GroupMembersWithoutNamedUsers">
	<sur:staffQueries>
	        <xsl:attribute name="threshold">
			<xsl:value-of select="$threshold"/>
		</xsl:attribute>
	    	<sur:usersOfGroup>
			<xsl:attribute name="groupName">
				<xsl:value-of select="staff:parameter[@id='GroupName']"/>
			</xsl:attribute>
		</sur:usersOfGroup>
		<sur:remove>
			<xsl:attribute name="value"><xsl:value-of select="staff:parameter[@id='NamedUsers']"/></xsl:attribute>
		</sur:remove>   			
	</sur:staffQueries>
  </xsl:template>
<!-- End template GroupMembersWithoutNamedUsers -->


<!-- Begin template PersonSearch -->
  <xsl:template name="PersonSearch">
    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <sur:search>
        <xsl:attribute name="pattern">
          <xsl:value-of select="staff:parameter[@id='UserID']"/>
        </xsl:attribute>
        <xsl:attribute name="type">user</xsl:attribute>
      </sur:search>
    </sur:staffQueries>
  </xsl:template>
<!-- End template PersonSearch -->



<!-- Begin template GroupSearch -->
  <xsl:template name="GroupSearch">
    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <sur:search>
        <xsl:attribute name="pattern">
          <xsl:value-of select="staff:parameter[@id='GroupID']"/>
        </xsl:attribute>
        <xsl:attribute name="type">group</xsl:attribute>
      </sur:search>
    </sur:staffQueries>
  </xsl:template>
<!-- End template GroupSearch -->



<!-- Begin template NativeQuery -->
  <xsl:template name="NativeQuery">
    <sur:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$threshold"/>
      </xsl:attribute>
      <!-- Allow multiple Native Query templates-->
      <xsl:choose>
        <!-- Template 'search' -->
        <xsl:when test="staff:parameter[@id='QueryTemplate']='search'">
          <sur:search>
            <xsl:attribute name="pattern">
              <xsl:value-of select="staff:parameter[@id='Query']"/>
            </xsl:attribute>
            <xsl:attribute name="type">
              <xsl:choose>
                <xsl:when test="staff:parameter[@id='AdditionalParameter1']='group'">group</xsl:when>
                <xsl:when test="staff:parameter[@id='AdditionalParameter1']='user'">user</xsl:when>
                <xsl:otherwise>
                  <xsl:message terminate="no">ERROR: Unexpected value: '<xsl:value-of select="staff:parameter[@id='AdditionalParameter1']"/>' for AdditionalParameter1. Supported values are 'user' and 'group'.</xsl:message>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:attribute>
          </sur:search>
        </xsl:when>
        <!-- Template 'user' -->
        <xsl:when test="staff:parameter[@id='QueryTemplate']='user'">
          <sur:user>
            <xsl:attribute name="name">
              <xsl:value-of select="staff:parameter[@id='Query']"/>
            </xsl:attribute>
          </sur:user>
        </xsl:when>
        <!-- Template 'usersOfGroup' -->
        <xsl:when test="staff:parameter[@id='QueryTemplate']='usersOfGroup'">
          <sur:usersOfGroup>
            <xsl:attribute name="groupName">
              <xsl:value-of select="staff:parameter[@id='Query']"/>
            </xsl:attribute>
          </sur:usersOfGroup>
        </xsl:when>
        <xsl:otherwise>
          <xsl:message terminate="no">ERROR: Native query template '<xsl:value-of select="staff:parameter[@id='QueryTemplate']"/>' is not supported by the UserRegistry XSL transformation. Supported values are: 'search', 'user' and 'usersOfGroup'.</xsl:message>
        </xsl:otherwise>
      </xsl:choose>
    </sur:staffQueries>
  </xsl:template>
<!-- End template NativeQuery -->



<!-- Begin template Everybody -->
  <xsl:template name="Everybody">
    <sur:staffQueries>
      <sur:everybody/>
    </sur:staffQueries>
  </xsl:template>
<!-- End template Everybody -->



<!-- Begin template Nobody -->
  <xsl:template name="Nobody">
    <sur:staffQueries>
      <sur:nobody/>
    </sur:staffQueries>
  </xsl:template>
<!-- End template Nobody -->
</xsl:transform>